@@ -123,6 +123,8 @@ class Project(command.Base, ContainerAware):
     def test(self):
         """Runs the unit tests for the project.
         """
+        current_directory = os.getcwd()
+        os.chdir(os.path.join(current_directory, '..'))
         try:
             app_module = os.environ['APP_MODULE']
             test_runner = None
@@ -144,6 +146,7 @@ class Project(command.Base, ContainerAware):
                     "You must install either 'nose' or 'py.test' to run the unit tests.")
         except:
             _no_application_error()
+        os.chdir(current_directory)
 
     @arg('path', optional=True)
     @arg('method', optional=True)
@@ -226,7 +229,7 @@ routes = {
 """
 
 PROD_CONFIG_PY_TEMPLATE = """# -*- coding: utf-8 -*-
-from ${app_name}.config.routes import routes
+from ${app_name}.config.routes import routes  # noqa
 
 
 debug = {
@@ -235,7 +238,7 @@ debug = {
 """
 
 DEV_CONFIG_PY_TEMPLATE = """# -*- coding: utf-8 -*-
-from ${app_name}.config.routes import routes
+from ${app_name}.config.routes import routes  # noqa
 
 
 debug = {
@@ -289,27 +292,27 @@ CONSOLE_TEMPLATE = """#!/usr/bin/env python
 import os
 import sys
 
-import os
-import sys
-
 SCRIPT_DIR, SCRIPT_FILE = os.path.split(os.path.abspath(__file__))
 os.environ.update({
     'APP_MODULE': '${app_name}',
+    'APP_SETTINGS': '${app_name}.config',
     'APP_DIR': os.path.join(SCRIPT_DIR, '${app_name}'),
     'PUBLIC_DIR': os.path.join(SCRIPT_DIR, 'public'),
     'SCRIPT_DIR': SCRIPT_DIR
 })
+os.chdir(os.environ['APP_DIR'])
+
 try:
-    import watson
+    from watson.framework import applications
+    from watson.common import imports
 except:
-    sys.stdout.write('You must have Watson installed, please run `pip install watson-framework`\\n')
+    sys.stdout.write(
+        'You must have Watson installed, please run `pip install watson-framework`\\n')
     sys.exit(1)
 
-from watson.framework import applications
-from ${app_name}.config import config
 
 if __name__ == '__main__':
-    os.chdir(os.environ['APP_DIR'])
-    application = applications.Console(config)
+    config = imports.import_module(os.environ['APP_SETTINGS'])
+    application = applications.Console()
     application()
 """
