@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # Global functions for Jinja2 templates
 from watson.di import ContainerAware
+from watson.framework import controllers
 from jinja2 import contextfunction
 
 
@@ -13,8 +14,18 @@ class Url(ContainerAware):
 
         url('route_name', keyword=arg)
     """
+
+    __ioc_definition__ = {
+        'init': {
+            'router': 'router'
+        }
+    }
+
+    def __init__(self, router):
+        self.router = router
+
     def __call__(self, route_name, host=None, scheme=None, **kwargs):
-        path = self.container.get('router').assemble(route_name, **kwargs)
+        path = self.router.assemble(route_name, **kwargs)
         if host:
             path = '{0}{1}'.format(host, path)
         if scheme:
@@ -28,8 +39,18 @@ url = Url  # alias to Url
 class Config(ContainerAware):
     """Convenience method to retrieve the configuration of the application.
     """
+
+    __ioc_definition__ = {
+        'init': {
+            'application': 'application'
+        }
+    }
+
+    def __init__(self, application):
+        self.application = application
+
     def __call__(self, **kwargs):
-        return self.container.get('application').config
+        return self.application.config
 
 
 config = Config  # alias to Config
@@ -60,6 +81,11 @@ def flash_messages(context):
 
         {{ flash_messages() }}
     """
-    if 'flash_messages' not in context['context']:
-        return {}
+    app_context = context['context']
+    if 'flash_messages' not in app_context:
+        if 'request' in app_context and app_context['request'].session:
+            app_context['flash_messages'] = controllers.FlashMessagesContainer(
+                app_context['request'].session)
+        else:
+            app_context['flash_messages'] = {}
     return context['context']['flash_messages']
